"""
OPCUA to ERP5 OPCUA Document setter / getter glue script.
"""

import json
from erp5.component.module.Log import log

def convertNodeValue(node_id, node_value):
  """
  Based on node_id convert to proper Python type. Based on this format:
  ns=<namespaceindex>;<type>=<value>

  XXX: handle rest of datatypes!
  """
  node_type = node_id.split(";")[1]
  if node_type.startswith("s"):
    node_value = str(node_value)
  if node_type.startswith("i"):
    node_value = int(node_value)
  return node_value

# XXX: what should be the OPCUA container?
default_id = "1"
default_opcua_document = context.opcua_document_module.get(default_id, None)
if default_opcua_document is None:
  context.opcua_document_module.newContent(portal_type = "OPCUA Document",
                                           id = default_id)

# do selection of oepration in a REST fashion based in HTTP method
http_method = context.REQUEST.method
context.log(http_method)

if http_method == "GET":
  # assume read request, return  what was saved.
  return json.dumps(default_opcua_document.getNodeDict())
elif http_method == "POST":
  # assume write request
  try:
    data = context.REQUEST.data
  except AttributeError as e:
    log("Warning: 'data' is missing from request.")
    raise e
  else:
    data = json.loads(data)
    if 'node' in data.keys():
      # log only set requests for now
      node_id = data['node']
      node_value = data['val']
      # set to  "ERP5 OPCUA Document" but only if it's not a None value
      if node_value is not None and node_value != "None":
        log("Set '%s' =  '%s' to %s as %s" %(node_id, node_value, default_opcua_document, node_id))
        node_dict = default_opcua_document.getNodeDict()
        node_dict[node_id] = convertNodeValue(node_id, node_value)
        default_opcua_document.setNodeDict(node_dict)
        log("Changed = %s" %default_opcua_document.getNodeDict())
